@@ -5,8 +5,6 @@ from threading import Thread
 
 from .utils import get_response_json
 
-warnings.simplefilter("always")
-
 
 def initialize(library='featuretools'):
     bg_thread = Thread(target=check_version, kwargs={'library': library})
@@ -15,12 +13,11 @@ def initialize(library='featuretools'):
 
 def check_version(library='featuretools', version=None, headers={}):
     update_check = os.environ.get('ALTERYX_OPEN_SRC_UPDATE_CHECKER', True)
-    with warnings.catch_warnings():
-        warnings.simplefilter('ignore')
-        try:
-            lib = import_module(library)
-        except Exception:
-            return
+    try:
+        lib = import_module(library)
+    except Exception:
+        return
+
     if version is None:
         version = lib.__version__
 
